%global pypi_name packaging

# Specify --with bootstrap to build in bootstrap mode
# This mode is needed, because python3-rpm-generators need packaging
# When bootstrapping, disable tests and docs as well.
%bcond_with bootstrap

%bcond_with docs

Name:           python-packaging
Version:        24.2
Release:        %mkrel 3
Group:          Development/Python
Summary:        Core utilities for Python packages

License:        BSD or ASL 2.0
URL:            https://github.com/pypa/packaging
Source0:        %{pypi_source}
BuildArch:      noarch

BuildRequires:  pkgconfig(python3)
BuildRequires:  pyproject-rpm-macros
%if %{with bootstrap}
BuildRequires:  python3dist(flit-core)
%endif

%if %{with docs}
BuildRequires:  python3dist(sphinx)
%endif

%description
packaging Core utilities for Python packages

%package -n     python3-%{pypi_name}
Summary:        Core utilities for Python packages
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
%if %{with bootstrap}
Provides:       python%{python3_pkgversion}dist(packaging) = %{version}
Provides:       python%{python3_version}dist(packaging) = %{version}
Requires:       python(abi) = %{python3_version}
%endif

%description -n python3-%{pypi_name}
packaging Core utilities for Python packages

%prep
%setup -q -n %{pypi_name}-%{version}


%if %{without bootstrap}
%generate_buildrequires
%pyproject_buildrequires -r
%endif


%build
%if %{with bootstrap}
%{python3} -m flit_core.wheel
%else
%pyproject_wheel
%endif

%if %{with docs}
# generate html docs
PYTHONPATCH=$(pwd) sphinx-build docs html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
# Do not bundle fonts
rm -rf html/_static/fonts/
%endif


%install
%if %{with bootstrap}
mkdir -p %{buildroot}%{python3_sitelib}
unzip dist/packaging-%{version}-py3-none-any.whl -d %{buildroot}%{python3_sitelib} -x packaging-%{version}.dist-info/RECORD
echo '%{python3_sitelib}/packaging*' > %{pyproject_files}
%else
%pyproject_install
%pyproject_save_files %{pypi_name}
%endif

%files -n python3-%{pypi_name}  -f %{pyproject_files}
%doc README.rst


%changelog
* Thu Feb 20 2025 wally <wally> 24.2-3.mga10
+ Revision: 2150164
- non-bootstrap build for python3.13

* Thu Feb 20 2025 wally <wally> 24.2-2.mga10
+ Revision: 2150136
- bootstrap build for python3.13

* Mon Feb 10 2025 daviddavid <daviddavid> 24.2-1.mga10
+ Revision: 2146657
- new version: 24.2

* Wed Apr 03 2024 papoteur <papoteur> 24.0-1.mga10
+ Revision: 2054134
- new version 24.0

* Thu Dec 07 2023 wally <wally> 23.1-3.mga10
+ Revision: 2014666
- non-bootstrap build for py3.12 update

* Thu Dec 07 2023 wally <wally> 23.1-2.mga10
+ Revision: 2014557
- bootstrap build for py3.12 update

* Fri Apr 21 2023 kekepower <kekepower> 23.1-1.mga9
+ Revision: 1953794
- Update to version 23.1

* Sun Jan 22 2023 wally <wally> 23.0-2.mga9
+ Revision: 1934858
- build without subrel

* Sun Jan 22 2023 wally <wally> 23.0-1.1.mga9
+ Revision: 1934851
- new version 23.0

* Sat Jan 21 2023 kekepower <kekepower> 22.0-1.1.mga9
+ Revision: 1934734
- Update to version 22.0

* Wed Mar 23 2022 umeabot <umeabot> 21.3-4.mga9
+ Revision: 1822108
- Mageia 9 Mass Rebuild

* Sat Feb 05 2022 wally <wally> 21.3-3.mga9
+ Revision: 1771659
- enable pyparsing dep again

* Sat Feb 05 2022 wally <wally> 21.3-2.mga9
+ Revision: 1771636
- temporary disable pyparsing dep

* Sat Feb 05 2022 wally <wally> 21.3-1.mga9
+ Revision: 1771605
- new version 21.3
- bootstrap build for python 3.10

* Sun Aug 29 2021 wally <wally> 21.0-1.mga9
+ Revision: 1743464
- new version 21.0

* Sun Mar 14 2021 wally <wally> 20.9-3.mga9
+ Revision: 1702692
- disable bootstrap mode

* Sun Mar 14 2021 wally <wally> 20.9-2.mga9
+ Revision: 1702513
- bootstrap build for new python 3.9

* Sat Mar 13 2021 wally <wally> 20.9-1.mga9
+ Revision: 1702272
- new version 20.9 (sync with Fedora)
+ daviddavid <daviddavid>
- new version: 20.7

* Fri Jun 12 2020 kekepower <kekepower> 20.4-1.mga8
+ Revision: 1592971
- Update to version 20.4

* Thu Apr 09 2020 kekepower <kekepower> 20.3-1.mga8
+ Revision: 1565696
- Update to version 20.3

* Sun Feb 16 2020 umeabot <umeabot> 19.1-2.mga8
+ Revision: 1530874
- Mageia 8 Mass Rebuild

* Thu Sep 05 2019 wally <wally> 19.1-1.mga8
+ Revision: 1437607
- new version 19.1
- drop python2 support
- rebuild for python3.8

* Tue Jan 29 2019 kekepower <kekepower> 19.0-1.mga7
+ Revision: 1361778
- Update to version 19.0

* Sat Jan 05 2019 wally <wally> 18.0-2.mga7
+ Revision: 1349667
- rebuild for python3.7

* Sat Nov 03 2018 kekepower <kekepower> 18.0-1.mga7
+ Revision: 1327793
- Update to version 18.0

* Thu Sep 20 2018 umeabot <umeabot> 17.1-2.mga7
+ Revision: 1289508
- Mageia 7 Mass Rebuild

* Sat Mar 10 2018 kekepower <kekepower> 17.1-1.mga7
+ Revision: 1207915
- Update to version 17.1

* Mon Feb 19 2018 kekepower <kekepower> 16.8-1.mga7
+ Revision: 1203183
- imported package python-packaging

